@@ -6,7 +6,7 @@ package utils
 import (
 	"testing"
 
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
 	"github.com/weaveworks/eksctl/integration/tests"
@@ -25,9 +25,6 @@ func TestUtils(t *testing.T) {
 	testutils.RegisterAndRun(t)
 }
 
-var _ = BeforeSuite(func() {
-})
-
 var _ = Describe("Utils", func() {
 	Context("schema", func() {
 		It("displays the schema", func() {
